==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/hu.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Külső tárolók",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Grant access" : "Megadom a hozzáférést",
    "Error configuring OAuth1" : "OAuth1 konfigurálási hiba",
    "Please provide a valid app key and secret." : "Kérlek adj meg egy érvényes alkalmazás kulcsot és jelszót.",
    "Error configuring OAuth2" : "OAuth2 konfigurálási hiba",
    "Generate keys" : "Kulcsok generálása",
    "Error generating key pair" : "Hiba történt a kulcspár generálása közben",
    "All users. Type to select user or group." : "Összes felhasználó. Írj be egy felhasználót vagy csoportot.",
    "(group)" : "(csoport)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitás a Mac NFD kódolással (lassú)",
    "Admin defined" : "Adminisztrátor definiálva",
    "Saved" : "Elmentve",
    "Saving..." : "Mentés...",
    "Save" : "Mentés",
    "Empty response from the server" : "Üres válasz a szervertől",
    "Couldn't get the information from the remote server: {code} {type}" : "Nem sikerült lekérdezni az információkat a távoli szerverről: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nem lehet letölteni a külső csatolási pontok listáját: {type}",
    "There was an error with message: " : "Hiba történt ezzel az üzenettel:",
    "External mount error" : "Külső csatolási hiba",
    "external-storage" : "külső tároló",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Néhány beállított külső csatolási pont nincs kapcsolatban. További információkért kattints a piros sor(ok)ra.",
    "Please enter the credentials for the {mount} mount" : "Kérlek add meg a következő csatolás azonosítóit: {mount}",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Credentials saved" : "Azonosítók mentve",
    "Credentials saving failed" : "Azonosítók mentése sikertelen",
    "Credentials required" : "Azonosító szükséges",
    "Invalid mount point" : "Érvénytelen csatolási pont",
    "Insufficient data: %s" : "Nem elegendő adat: %s",
    "%s" : "%s",
    "Access key" : "Hozzáférési kulcs",
    "Secret key" : "Titkos kulcs",
    "Builtin" : "Beépített",
    "None" : "Egyik sem",
    "OAuth1" : "OAuth1",
    "App key" : "Alkalmazás kulcs",
    "App secret" : "Alkalmazás titkos kulcs",
    "OAuth2" : "OAuth2",
    "Client ID" : "Ügyfél ID",
    "Client secret" : "Kliens titok",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Bérlő neve",
    "Identity endpoint URL" : "Identitás végpont URL",
    "Rackspace" : "Rackspace",
    "API key" : "API kulcs",
    "Global credentials" : "Globális azonosítók",
    "Log-in credentials, save in database" : "Bejelentkezési azonosítók, mentés az adatbázisban",
    "Username and password" : "Felhasználónév és jelszó",
    "Log-in credentials, save in session" : "Bejelentkezési azonosítók, mentés az munkamenetben",
    "User entered, store in database" : "Felhasználó megadva, tárolás az adatbázisban",
    "RSA public key" : "RSA nyilvános kulcs",
    "Public key" : "Nyilvános kulcs",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hosztnév",
    "Port" : "Port",
    "Region" : "Megye",
    "Enable SSL" : "SSL engedélyezése",
    "Enable Path Style" : "Útvonal stílus engedélyezés",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Távoli almappa",
    "Secure https://" : "Biztonságos https://",
    "FTP" : "FTP",
    "Host" : "Kiszolgáló",
    "Secure ftps://" : "Biztonságos ftps://",
    "Local" : "Helyi",
    "Location" : "Hely",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Gyökér",
    "SFTP with secret key login" : "SFTP titkos kulcs belépéssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Megosztás",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS OC belépéssel",
    "Username as share" : "Felhasználónév és megosztás",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Szolgáltatás neve",
    "Request timeout (seconds)" : "Időtúllépés (másodperc)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A cURL támogatás, a PHP-ban nincs engedélyezve vagy telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Az FTP támogatás, a PHP-ban nincs engedélyezve vagy telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "%s nincs telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "No external storage configured" : "Nincs külső tároló beállítva.",
    "You can add external storages in the personal settings" : "Hozzáadhatsz külső tárolókat a személyes beállítások közt.",
    "Name" : "Név",
    "Storage type" : "Tároló típusa",
    "Scope" : "Hatáskör",
    "Enable encryption" : "Titkosítás engedélyezése",
    "Enable previews" : "Előnézet engedélyezése",
    "Enable sharing" : "Megosztás engedélyezése",
    "Check for changes" : "Változások keresése",
    "Never" : "Soha",
    "Once every direct access" : "Minden közvetlen elérésnél",
    "Folder name" : "Mappa neve",
    "External storage" : "Külső tárolók",
    "Authentication" : "Azonisítás",
    "Configuration" : "Beállítások",
    "Available for" : "Elérhető számukra",
    "Add storage" : "Tároló becsatolása",
    "Advanced settings" : "Haladó beállítások",
    "Delete" : "Törlés",
    "Allow users to mount external storage" : "Külső tárolók csatolásának  engedélyezése a felhasználók részére",
    "Allow users to mount the following external storage" : "A felhasználók számára engedélyezett külső tárolók csatolása:",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Nem sikerült a kérési tokenek letöltése. Ellenőrizd, hogy az alkalmazás kulcs és titok megfelelő-e!",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Nem sikerült a hozzáférési tokenek letöltése. Ellenőrizd, hogy az alkalmazás kulcs és titok megfelelő-e!",
    "Step 1 failed. Exception: %s" : "1. lépés sikertelen. Kivétel: %s",
    "Step 2 failed. Exception: %s" : "2. lépés sikertelen. Kivétel: %s",
    "Dropbox App Configuration" : "Dropbox alkalmazás beállítás",
    "Google Drive App Configuration" : "Google Drive alkalmazás beállítás",
    "Storage with id \"%i\" not found" : "A következő azonosítójú tároló nem található: \"%i\"",
    "Storage with id \"%i\" is not user editable" : "A következő azonosítójú tároló a felhasználó számára nem szerkeszthető: \"%i\"",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/hu.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Külső tárolók",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Grant access" : "Megadom a hozzáférést",
    "Error configuring OAuth1" : "OAuth1 konfigurálási hiba",
    "Please provide a valid app key and secret." : "Kérlek adj meg egy érvényes alkalmazás kulcsot és jelszót.",
    "Error configuring OAuth2" : "OAuth2 konfigurálási hiba",
    "Generate keys" : "Kulcsok generálása",
    "Error generating key pair" : "Hiba történt a kulcspár generálása közben",
    "All users. Type to select user or group." : "Összes felhasználó. Írj be egy felhasználót vagy csoportot.",
    "(group)" : "(csoport)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitás a Mac NFD kódolással (lassú)",
    "Admin defined" : "Adminisztrátor definiálva",
    "Are you sure you want to delete this external storage" : "Biztosan törlöd ezt a külső tárolót",
    "Delete storage?" : "Tároló törlése?",
    "Saved" : "Elmentve",
    "Saving..." : "Mentés...",
    "Save" : "Mentés",
    "Empty response from the server" : "Üres válasz a szervertől",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nem hozzáférhető. Kérjük lépj ki és be ismét a csatolási pont aktiválásához",
    "Couldn't get the information from the remote server: {code} {type}" : "Nem sikerült lekérdezni az információkat a távoli szerverről: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nem lehet letölteni a külső csatolási pontok listáját: {type}",
    "There was an error with message: " : "Hiba történt ezzel az üzenettel:",
    "External mount error" : "Külső csatolási hiba",
    "external-storage" : "külső tároló",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "A Windows megosztások listája nem begyűjthető: üres válasz a szervertől",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Néhány beállított külső csatolási pont nincs kapcsolatban. További információkért kattints a piros sor(ok)ra.",
    "Please enter the credentials for the {mount} mount" : "Kérlek add meg a következő csatolás azonosítóit: {mount}",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Credentials saved" : "Azonosítók mentve",
    "Credentials saving failed" : "Azonosítók mentése sikertelen",
    "Credentials required" : "Azonosító szükséges",
    "Storage with ID \"%d\" not found" : "A(z) \"%d\" azonosítójú tároló nincs meg",
    "Invalid backend or authentication mechanism class" : "Érvénytelen háttér vagy autentikációs mechanizmus osztály",
    "Invalid mount point" : "Érvénytelen csatolási pont",
    "Objectstore forbidden" : "Objektumtár tiltott",
    "Invalid storage backend \"%s\"" : "Érvénytelen háttértár kezelő \"%s\"",
    "Not permitted to use backend \"%s\"" : "A(z) \"%s\" háttér használata nem engedélyezett",
    "Not permitted to use authentication mechanism \"%s\"" : "Nem engedélyezett a \"%s\" autentikációs mechanizmus használata",
    "Unsatisfied backend parameters" : "Elégtelen háttér adatok",
    "Unsatisfied authentication mechanism parameters" : "Elégtelen autentikációs mechanizmus paraméterek",
    "Insufficient data: %s" : "Nem elegendő adat: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "A(z) \"%d\" azonosítójú tároló nem szerkeszthető a felhasználók által",
    "Access key" : "Hozzáférési kulcs",
    "Secret key" : "Titkos kulcs",
    "Builtin" : "Beépített",
    "None" : "Egyik sem",
    "OAuth1" : "OAuth1",
    "App key" : "Alkalmazás kulcs",
    "App secret" : "Alkalmazás titkos kulcs",
    "OAuth2" : "OAuth2",
    "Client ID" : "Ügyfél ID",
    "Client secret" : "Kliens titok",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Bérlő neve",
    "Identity endpoint URL" : "Identitás végpont URL",
    "Rackspace" : "Rackspace",
    "API key" : "API kulcs",
    "Global credentials" : "Globális azonosítók",
    "Log-in credentials, save in database" : "Bejelentkezési azonosítók, mentés az adatbázisban",
    "Username and password" : "Felhasználónév és jelszó",
    "Log-in credentials, save in session" : "Bejelentkezési azonosítók, mentés az munkamenetben",
    "User entered, store in database" : "Felhasználó megadva, tárolás az adatbázisban",
    "RSA public key" : "RSA nyilvános kulcs",
    "Public key" : "Nyilvános kulcs",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hosztnév",
    "Port" : "Port",
    "Region" : "Megye",
    "Enable SSL" : "SSL engedélyezése",
    "Enable Path Style" : "Útvonal stílus engedélyezés",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Távoli almappa",
    "Secure https://" : "Biztonságos https://",
    "FTP" : "FTP",
    "Host" : "Kiszolgáló",
    "Secure ftps://" : "Biztonságos ftps://",
    "Local" : "Helyi",
    "Location" : "Hely",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Gyökér",
    "SFTP with secret key login" : "SFTP titkos kulcs belépéssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Megosztás",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS OC belépéssel",
    "Username as share" : "Felhasználónév és megosztás",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Szolgáltatás neve",
    "Request timeout (seconds)" : "Időtúllépés (másodperc)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A cURL támogatás, a PHP-ban nincs engedélyezve vagy telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Az FTP támogatás, a PHP-ban nincs engedélyezve vagy telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "%s nincs telepítve. %s csatolása lehetetlen. Kérd meg a rendszergazdádat, hogy telepítse.",
    "No external storage configured" : "Nincs külső tároló beállítva.",
    "You can add external storages in the personal settings" : "Hozzáadhatsz külső tárolókat a személyes beállítások közt.",
    "Name" : "Név",
    "Storage type" : "Tároló típusa",
    "Scope" : "Hatáskör",
    "Enable encryption" : "Titkosítás engedélyezése",
    "Enable previews" : "Előnézet engedélyezése",
    "Enable sharing" : "Megosztás engedélyezése",
    "Check for changes" : "Változások keresése",
    "Never" : "Soha",
    "Once every direct access" : "Minden közvetlen elérésnél",
    "Folder name" : "Mappa neve",
    "External storage" : "Külső tárolók",
    "Authentication" : "Azonisítás",
    "Configuration" : "Beállítások",
    "Available for" : "Elérhető számukra",
    "Add storage" : "Tároló becsatolása",
    "Advanced settings" : "Haladó beállítások",
    "Delete" : "Törlés",
    "Allow users to mount external storage" : "Külső tárolók csatolásának  engedélyezése a felhasználók részére",
    "Allow users to mount the following external storage" : "A felhasználók számára engedélyezett külső tárolók csatolása:",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Nem sikerült a kérési tokenek letöltése. Ellenőrizd, hogy az alkalmazás kulcs és titok megfelelő-e!",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Nem sikerült a hozzáférési tokenek letöltése. Ellenőrizd, hogy az alkalmazás kulcs és titok megfelelő-e!",
    "Step 1 failed. Exception: %s" : "1. lépés sikertelen. Kivétel: %s",
    "Step 2 failed. Exception: %s" : "2. lépés sikertelen. Kivétel: %s",
    "Dropbox App Configuration" : "Dropbox alkalmazás beállítás",
    "Google Drive App Configuration" : "Google Drive alkalmazás beállítás",
    "Storage with id \"%i\" not found" : "A következő azonosítójú tároló nem található: \"%i\"",
    "Storage with id \"%i\" is not user editable" : "A következő azonosítójú tároló a felhasználó számára nem szerkeszthető: \"%i\"",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
